@@ -20,6 +20,7 @@ pub struct ImageLink {
     /// 2: right
     pub layout: Option<ImageLayout>,
     pub size: Option<(usize, usize)>,
+    pub linkable: Option<HyperLink>,
     pub options: Option<CommandOptions>,
 }
 
@@ -45,7 +46,7 @@ impl ImageLink {
             None => return self,
             Some(s) => s,
         };
-        options.extract_string_key("alt").map(|f| self.set_alt(f));
+        options.get_string_key("alt").map(|f| self.set_alt(f));
         return self;
     }
 }
