@@ -7,8 +7,8 @@ mod value;
 
 pub use self::{
     elements::*,
-    link::{EmailLink, HyperLink, HyperLinkTarget, ImageLayout, ImageLink, SmartLink, TagReference, TwoWayLink},
-    list::ListView,
+    link::{EmailLink, HyperLink, HyperLinkTarget, ImageLayout, ImageLink, ResourceDescriptor, SmartLink, TagReference, TwoWayLink},
+    list::{ListDetailedNode, ListPrefixSymbol, ListSimpleNode, ListView},
     literal::Literal,
     table::TableView,
     value::{Value, ValueType},
@@ -48,7 +48,7 @@ pub enum ASTKind {
     ///
     TableView(Box<TableView>),
     ///
-    ListView(Box<ListView>),
+    ListView(ListView),
     /// block: ``` a ```
     /// span: `` `code`  ``
     CodeNode(Box<CodeNode>),
